// DO NOT EDIT!  Generated automatically by mk-builtins.pl.

#if ! defined (octave_builtin_defun_decls_h)
#define octave_builtin_defun_decls_h 1

#include "octave-config.h"

#include "ovl.h"

OCTAVE_NAMESPACE_BEGIN

class interpreter;

// Methods

extern OCTINTERP_API octave_value_list
FEDITOR (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
FEXEC_PATH (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
FIMAGE_PATH (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
FPAGER (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
FPAGER_FLAGS (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
FPS1 (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
FPS2 (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
FPS4 (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__builtins__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__calc_dimensions__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__db_next_breakpoint_quiet__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__display_tokens__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__dump_load_path__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__dump_symtab_info__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__dump_typeinfo__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__eigs__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__event_manager_apply_preferences__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__event_manager_copy_image_to_clipboard__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__event_manager_edit_file__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__event_manager_enabled__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__event_manager_file_dialog__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__event_manager_file_remove__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__event_manager_file_renamed__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__event_manager_gui_preference__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__event_manager_gui_status_update__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__event_manager_have_dialogs__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__event_manager_input_dialog__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__event_manager_list_dialog__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__event_manager_named_icon__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__event_manager_question_dialog__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__event_manager_register_documentation__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__event_manager_show_command_history__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__event_manager_show_community_news__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__event_manager_show_documentation__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__event_manager_show_file_browser__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__event_manager_show_preferences__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__event_manager_show_release_notes__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__event_manager_show_terminal_window__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__event_manager_show_workspace__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__event_manager_unregister_documentation__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__event_manager_update_gui_lexer__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__ftp__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__ftp_ascii__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__ftp_binary__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__ftp_close__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__ftp_cwd__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__ftp_delete__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__ftp_dir__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__ftp_mget__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__ftp_mkdir__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__ftp_mode__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__ftp_mput__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__ftp_pwd__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__ftp_rename__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__ftp_rmdir__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__get__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__get_cmdline_fcn_txt__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__get_frame__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__get_position__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__go_axes__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__go_delete__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__go_execute_callback__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__go_figure__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__go_figure_handles__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__go_handles__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__go_hggroup__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__go_image__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__go_light__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__go_line__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__go_patch__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__go_post_callback__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__go_scatter__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__go_surface__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__go_text__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__go_uibuttongroup__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__go_uicontextmenu__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__go_uicontrol__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__go_uimenu__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__go_uipanel__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__go_uipushtool__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__go_uitable__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__go_uitoggletool__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__go_uitoolbar__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__gud_mode__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__image_pixel_size__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__lexer_debug_flag__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__list_functions__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__methods__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__mfile_encoding__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__parse_file__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__pathorig__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__profiler_data__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__profiler_enable__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__profiler_reset__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__request_drawnow__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__show_figure__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__textscan__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__token_count__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__traditional__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__update_normals__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__varval__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__which__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__zoom__ (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fadd_input_event_hook (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Faddlistener (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Faddpath (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Faddproperty (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Farrayfun (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fassignin (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fatexit (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fauto_repeat_debug_command (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fautoload (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Favailable_graphics_toolkits (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fbeep_on_error (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fbsxfun (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fbuilt_in_docstrings_file (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fbuiltin (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fcd (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fcellfun (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fclass (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fclear (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fcommand_line_path (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fcommandhistory (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fcommandwindow (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fcompletion_append_char (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fcrash_dumps_octave_core (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fdaspk (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fdasrt (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fdassl (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fdbclear (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fdbcont (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fdbdown (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fdblist (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fdbquit (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fdbstack (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fdbstatus (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fdbstep (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fdbstop (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fdbtype (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fdbup (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fdbwhere (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fdebug_on_error (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fdebug_on_warning (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fdellistener (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fdesktop (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fdiary (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fdir_encoding (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fdir_in_loadpath (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fdlmread (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fdoc_cache_file (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fdrawnow (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fdup2 (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fecho (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fedit_history (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fend (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Ferror (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Feval (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fevalc (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fevalin (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fexec (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fexist (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Ffclear (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Ffclose (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Ffcntl (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Ffdisp (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Ffeof (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fferror (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Ffeval (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Ffflush (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Ffgetl (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Ffgets (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Ffile_in_loadpath (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Ffilebrowser (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Ffopen (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Ffork (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Ffprintf (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Ffputs (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Ffread (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Ffreport (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Ffrewind (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Ffscanf (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Ffseek (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Ffskipl (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fftell (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Ffwrite (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fget (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fget_help_text (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fget_help_text_from_file (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fhave_window_system (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fhistory (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fhistory_timestamp_format_string (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Finferiorto (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Finfo_file (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Finfo_program (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Finput (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fisargout (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fisdebugmode (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fisglobal (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fishghandle (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fisindex (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fkbhit (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fkeyboard (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Flasterr (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Flasterror (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Flastwarn (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fload (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Floaded_graphics_toolkits (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Flocalfunctions (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Flsode (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fmakeinfo_program (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fmax_recursion_depth (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fmax_stack_depth (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fmfilename (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fmislocked (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fmkstemp (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fmlock (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fmore (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fmunlock (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fnargin (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fnargout (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Foctave_core_file_limit (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Foctave_core_file_name (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Foctave_core_file_options (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fopenvar (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fpage_output_immediately (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fpage_screen_output (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fpath (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fpause (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fpclose (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fpipe (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fpopen (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fpopen2 (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fprintf (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fputs (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fquad (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fquadcc (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fquit (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fregister_graphics_toolkit (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fremove_input_event_hook (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Frename (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Freset (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Frestoredefaultpath (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Frethrow (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Frmdir (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Frmpath (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Frun_history (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fsave (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fsave_default_options (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fsave_header_format_string (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fscanf (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fset (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fsilent_functions (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fsource (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fstat (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fstderr (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fstdin (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fstdout (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fstr2func (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fstring_fill_char (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fsuperiorto (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fsuppress_verbose_help_message (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Ftexi_macros_file (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Ftextscan (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Ftmpfile (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Ftypeinfo (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Funlink (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fwaitfor (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fwarning (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fwho (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fwhos (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fwhos_line_format (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fworkspace (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fyes_or_no (octave::interpreter&, const octave_value_list& = octave_value_list (), int = 0);

// Functions

extern OCTINTERP_API octave_value_list
FF_DUPFD (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
FF_GETFD (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
FF_GETFL (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
FF_SETFD (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
FF_SETFL (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
FI (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
FInf (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
FNA (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
FNaN (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
FOCTAVE_EXEC_HOME (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
FOCTAVE_HOME (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
FOCTAVE_VERSION (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
FO_APPEND (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
FO_ASYNC (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
FO_CREAT (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
FO_EXCL (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
FO_NONBLOCK (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
FO_RDONLY (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
FO_RDWR (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
FO_SYNC (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
FO_TRUNC (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
FO_WRONLY (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
FP_tmpdir (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
FSEEK_CUR (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
FSEEK_END (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
FSEEK_SET (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
FSIG (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
FS_ISBLK (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
FS_ISCHR (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
FS_ISDIR (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
FS_ISFIFO (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
FS_ISLNK (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
FS_ISREG (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
FS_ISSOCK (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
FWCONTINUE (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
FWCOREDUMP (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
FWEXITSTATUS (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
FWIFCONTINUED (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
FWIFEXITED (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
FWIFSIGNALED (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
FWIFSTOPPED (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
FWNOHANG (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
FWSTOPSIG (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
FWTERMSIG (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
FWUNTRACED (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__accumarray_max__ (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__accumarray_min__ (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__accumarray_sum__ (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__accumdim_sum__ (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__base64_decode_bytes__ (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__betainc__ (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__blas_version__ (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__contourc__ (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__dsearchn__ (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__expint__ (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__fieldnames__ (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__fnmatch__ (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__gammainc__ (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__get_system_fonts__ (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__ichol0__ (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__icholt__ (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__ilu0__ (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__iluc__ (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__ilutp__ (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__inline_ctor__ (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__is_elevated_process__ (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__is_handle_visible__ (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__isprimelarge__ (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__java2mat__ (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__java_exit__ (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__java_get__ (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__java_init__ (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__java_set__ (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__lapack_version__ (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__lin_interpn__ (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__locale_charset__ (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__magick_finfo__ (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__magick_formats__ (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__magick_ping__ (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__magick_read__ (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__magick_write__ (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__make_valid_name__ (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__meta_get_package__ (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__mkdir__ (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__native2unicode__ (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__octave_config_info__ (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__open_with_system_app__ (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__operators__ (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__parent_classes__ (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__parser_debug_flag__ (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__pchip_deriv__ (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__qp__ (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__restful_service__ (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__sort_rows_idx__ (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__streameuler2d__ (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__streameuler3d__ (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__u8_validate__ (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__unicode2native__ (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__unicode_length__ (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__version_info__ (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__wglob__ (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
F__wmemory__ (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fabs (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Facos (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Facosh (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fairy (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fall (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Famd (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fand (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fangle (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fany (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Farg (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fargv (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fasin (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fasinh (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fatan (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fatan2 (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fatanh (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fbalance (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fbase64_decode (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fbase64_encode (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fbesselh (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fbesseli (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fbesselj (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fbesselk (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fbessely (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fbitand (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fbitor (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fbitpack (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fbitshift (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fbitunpack (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fbitxor (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fblkmm (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fcanonicalize_file_name (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fcat (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fcbrt (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fccolamd (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fceil (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fcell (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fcell2struct (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fcellindexmat (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fcellslices (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fcellstr (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fchar (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fchol (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fchol2inv (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fcholdelete (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fcholinsert (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fcholinv (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fcholshift (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fcholupdate (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fclc (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fcmdline_options (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fcolamd (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fcolloc (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fcolon (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fcolumns (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fcompletion_matches (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fcomplex (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fconfirm_recursive_rmdir (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fconj (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fconv2 (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fconvn (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fcos (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fcosh (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fcputime (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fcsymamd (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fctranspose (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fcummax (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fcummin (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fcumprod (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fcumsum (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fdaspk_options (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fdasrt_options (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fdassl_options (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fdawson (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fdebug_java (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fdebug_on_interrupt (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fdet (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fdiag (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fdiff (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fdisp (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fdisplay (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fdmperm (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fdo_string_escapes (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fdot (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fdouble (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fe (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Feig (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fellipj (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fendgrent (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fendpwent (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Feps (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Feq (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Ferf (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Ferfc (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Ferfcinv (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Ferfcx (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Ferfi (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Ferfinv (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Ferrno (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Ferrno_list (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fetree (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fexp (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fexpm1 (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Feye (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Ffalse (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Ffft (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Ffft2 (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Ffftn (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Ffile_in_path (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Ffilesep (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Ffilter (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Ffind (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Ffix (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Ffixed_point_format (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fflintmax (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Ffloor (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fformat (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Ffull (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Ffunc2str (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Ffunctions (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fgamma (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fgcd (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fge (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fgenpath (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fget_home_directory (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fgetegid (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fgetenv (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fgeteuid (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fgetgid (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fgetgrent (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fgetgrgid (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fgetgrnam (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fgethostname (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fgetpgrp (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fgetpid (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fgetppid (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fgetpwent (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fgetpwnam (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fgetpwuid (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fgetrusage (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fgetuid (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fgivens (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fglob (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fgmtime (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fgsvd (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fgt (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fhash (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fhess (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fhex2num (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fhistory_control (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fhistory_file (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fhistory_save (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fhistory_size (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fhorzcat (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fhypot (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fifft (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fifft2 (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fifftn (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fignore_function_time_stamp (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fimag (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Find2sub (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fint16 (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fint32 (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fint64 (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fint8 (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fintmax (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fintmin (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Finv (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fipermute (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fis_absolute_filename (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fis_dq_string (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fis_function_handle (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fis_rooted_relative_filename (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fis_same_file (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fis_sq_string (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fisa (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fisalnum (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fisalpha (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fisascii (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fiscell (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fiscellstr (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fischar (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fiscntrl (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fiscolumn (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fiscomplex (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fisdigit (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fisempty (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fisfield (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fisfinite (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fisfloat (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fisgraph (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fisguirunning (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fisieee (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fisinf (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fisinteger (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fisjava (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fiskeyword (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fislogical (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fislower (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fismatrix (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fisna (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fisnan (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fisnull (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fisnumeric (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fisobject (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fisprint (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fispunct (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fisreal (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fisrow (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fisscalar (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fissorted (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fisspace (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fissparse (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fissquare (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fisstruct (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fisstudent (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fisupper (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fisvarname (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fisvector (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fisxdigit (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
FjavaMethod (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
FjavaObject (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fjava_matrix_autoconversion (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fjava_unsigned_autoconversion (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fjsondecode (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fjsonencode (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fkill (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fkron (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fldivide (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fle (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Flength (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Flgamma (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Flink (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Flinspace (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Flist_in_columns (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Flocaltime (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Flog (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Flog10 (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Flog1p (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Flog2 (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Flogical (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Flookup (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Flsode_options (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Flstat (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Flt (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Flu (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fluupdate (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fmake_absolute_filename (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fmat2cell (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fmatrix_type (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fmax (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fmerge (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fmetaclass (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fmgorth (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fmin (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fminus (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fmissing_component_hook (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fmissing_function_hook (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fmkfifo (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fmktime (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fmldivide (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fmod (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fmpower (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fmrdivide (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fmtimes (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fnative_float_format (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fndims (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fne (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fnewline (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fnnz (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fnorm (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fnot (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fnproc (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fnth_element (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fnum2cell (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fnum2hex (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fnumel (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fnumfields (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fnzmax (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
FonCleanup (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fones (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Foptimize_diagonal_matrix (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Foptimize_permutation_matrix (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Foptimize_range (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Foptimize_subsasgn_calls (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
For (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fordqz (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fordschur (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Foutput_precision (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fpathsep (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fpermute (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fpi (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fpinv (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fplus (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fpower (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fprint_empty_dimensions (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fprint_struct_array_contents (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fprod (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fprogram_invocation_name (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fprogram_name (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fproperties (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fpsi (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fpwd (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fqr (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fqrdelete (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fqrinsert (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fqrshift (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fqrupdate (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fquad_options (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fqz (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Frand (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Frande (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Frandg (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Frandn (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Frandp (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Frandperm (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Frats (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Frcond (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Frdivide (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Freaddir (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Freadline_re_read_init_file (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Freadline_read_init_file (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Freadlink (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Freal (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Frealmax (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Frealmin (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fregexp (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fregexpi (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fregexprep (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Frehash (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Frem (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Frepelems (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Freshape (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fresize (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Frmfield (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fround (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Froundb (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Frows (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Frsf2csf (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fsave_precision (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fschur (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fsetenv (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fsetgrent (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fsetpwent (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fsighup_dumps_octave_core (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fsign (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fsignbit (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fsigquit_dumps_octave_core (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fsigterm_dumps_octave_core (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fsin (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fsingle (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fsinh (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fsize (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fsize_equal (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fsizemax (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fsizeof (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fsort (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fspalloc (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fsparse (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fsparse_auto_mutate (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fsplit_long_rows (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fspparms (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fsprank (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fsprintf (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fsqrt (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fsqrtm (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fsqueeze (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fsscanf (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fstr2double (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fstrcmp (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fstrcmpi (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fstrfind (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fstrftime (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fstrncmp (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fstrncmpi (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fstrptime (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fstrrep (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fstruct (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fstruct2cell (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fstruct_levels_to_print (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fstrvcat (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fsub2ind (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fsubsasgn (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fsubsref (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fsum (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fsumsq (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fsvd (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fsvd_driver (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fsylvester (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fsymamd (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fsymbfact (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fsymlink (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fsymrcm (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fsystem (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Ftan (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Ftanh (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Ftempname (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fterminal_size (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Ftic (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Ftilde_expand (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Ftime (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Ftimes (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Ftoc (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Ftolower (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Ftoupper (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Ftranspose (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Ftril (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Ftriu (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Ftrue (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Ftsearch (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Ftypecast (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fuint16 (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fuint32 (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fuint64 (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fuint8 (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fumask (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fuminus (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Funame (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fundo_string_escapes (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Funicode_idx (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Funsetenv (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fuplus (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Furlread (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Furlwrite (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fuser_config_dir (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fuser_data_dir (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fvec (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fvertcat (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fwaitpid (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fwarranty (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fwinqueryreg (const octave_value_list& = octave_value_list (), int = 0);

extern OCTINTERP_API octave_value_list
Fzeros (const octave_value_list& = octave_value_list (), int = 0);


OCTAVE_NAMESPACE_END

#if defined (OCTAVE_PROVIDE_DEPRECATED_SYMBOLS)

OCTAVE_DEPRECATED (7, "use 'octave::FF_DUPFD' instead")
inline octave_value_list
FF_DUPFD (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::FF_DUPFD (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::FF_GETFD' instead")
inline octave_value_list
FF_GETFD (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::FF_GETFD (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::FF_GETFL' instead")
inline octave_value_list
FF_GETFL (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::FF_GETFL (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::FF_SETFD' instead")
inline octave_value_list
FF_SETFD (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::FF_SETFD (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::FF_SETFL' instead")
inline octave_value_list
FF_SETFL (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::FF_SETFL (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::FI' instead")
inline octave_value_list
FI (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::FI (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::FInf' instead")
inline octave_value_list
FInf (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::FInf (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::FNA' instead")
inline octave_value_list
FNA (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::FNA (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::FNaN' instead")
inline octave_value_list
FNaN (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::FNaN (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::FOCTAVE_EXEC_HOME' instead")
inline octave_value_list
FOCTAVE_EXEC_HOME (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::FOCTAVE_EXEC_HOME (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::FOCTAVE_HOME' instead")
inline octave_value_list
FOCTAVE_HOME (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::FOCTAVE_HOME (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::FOCTAVE_VERSION' instead")
inline octave_value_list
FOCTAVE_VERSION (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::FOCTAVE_VERSION (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::FO_APPEND' instead")
inline octave_value_list
FO_APPEND (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::FO_APPEND (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::FO_ASYNC' instead")
inline octave_value_list
FO_ASYNC (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::FO_ASYNC (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::FO_CREAT' instead")
inline octave_value_list
FO_CREAT (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::FO_CREAT (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::FO_EXCL' instead")
inline octave_value_list
FO_EXCL (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::FO_EXCL (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::FO_NONBLOCK' instead")
inline octave_value_list
FO_NONBLOCK (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::FO_NONBLOCK (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::FO_RDONLY' instead")
inline octave_value_list
FO_RDONLY (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::FO_RDONLY (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::FO_RDWR' instead")
inline octave_value_list
FO_RDWR (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::FO_RDWR (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::FO_SYNC' instead")
inline octave_value_list
FO_SYNC (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::FO_SYNC (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::FO_TRUNC' instead")
inline octave_value_list
FO_TRUNC (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::FO_TRUNC (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::FO_WRONLY' instead")
inline octave_value_list
FO_WRONLY (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::FO_WRONLY (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::FP_tmpdir' instead")
inline octave_value_list
FP_tmpdir (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::FP_tmpdir (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::FSEEK_CUR' instead")
inline octave_value_list
FSEEK_CUR (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::FSEEK_CUR (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::FSEEK_END' instead")
inline octave_value_list
FSEEK_END (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::FSEEK_END (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::FSEEK_SET' instead")
inline octave_value_list
FSEEK_SET (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::FSEEK_SET (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::FSIG' instead")
inline octave_value_list
FSIG (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::FSIG (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::FS_ISBLK' instead")
inline octave_value_list
FS_ISBLK (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::FS_ISBLK (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::FS_ISCHR' instead")
inline octave_value_list
FS_ISCHR (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::FS_ISCHR (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::FS_ISDIR' instead")
inline octave_value_list
FS_ISDIR (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::FS_ISDIR (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::FS_ISFIFO' instead")
inline octave_value_list
FS_ISFIFO (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::FS_ISFIFO (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::FS_ISLNK' instead")
inline octave_value_list
FS_ISLNK (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::FS_ISLNK (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::FS_ISREG' instead")
inline octave_value_list
FS_ISREG (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::FS_ISREG (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::FS_ISSOCK' instead")
inline octave_value_list
FS_ISSOCK (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::FS_ISSOCK (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::FWCONTINUE' instead")
inline octave_value_list
FWCONTINUE (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::FWCONTINUE (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::FWCOREDUMP' instead")
inline octave_value_list
FWCOREDUMP (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::FWCOREDUMP (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::FWEXITSTATUS' instead")
inline octave_value_list
FWEXITSTATUS (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::FWEXITSTATUS (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::FWIFCONTINUED' instead")
inline octave_value_list
FWIFCONTINUED (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::FWIFCONTINUED (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::FWIFEXITED' instead")
inline octave_value_list
FWIFEXITED (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::FWIFEXITED (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::FWIFSIGNALED' instead")
inline octave_value_list
FWIFSIGNALED (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::FWIFSIGNALED (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::FWIFSTOPPED' instead")
inline octave_value_list
FWIFSTOPPED (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::FWIFSTOPPED (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::FWNOHANG' instead")
inline octave_value_list
FWNOHANG (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::FWNOHANG (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::FWSTOPSIG' instead")
inline octave_value_list
FWSTOPSIG (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::FWSTOPSIG (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::FWTERMSIG' instead")
inline octave_value_list
FWTERMSIG (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::FWTERMSIG (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::FWUNTRACED' instead")
inline octave_value_list
FWUNTRACED (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::FWUNTRACED (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::F__accumarray_max__' instead")
inline octave_value_list
F__accumarray_max__ (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::F__accumarray_max__ (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::F__accumarray_min__' instead")
inline octave_value_list
F__accumarray_min__ (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::F__accumarray_min__ (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::F__accumarray_sum__' instead")
inline octave_value_list
F__accumarray_sum__ (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::F__accumarray_sum__ (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::F__accumdim_sum__' instead")
inline octave_value_list
F__accumdim_sum__ (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::F__accumdim_sum__ (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::F__base64_decode_bytes__' instead")
inline octave_value_list
F__base64_decode_bytes__ (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::F__base64_decode_bytes__ (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::F__betainc__' instead")
inline octave_value_list
F__betainc__ (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::F__betainc__ (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::F__blas_version__' instead")
inline octave_value_list
F__blas_version__ (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::F__blas_version__ (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::F__contourc__' instead")
inline octave_value_list
F__contourc__ (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::F__contourc__ (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::F__dsearchn__' instead")
inline octave_value_list
F__dsearchn__ (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::F__dsearchn__ (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::F__expint__' instead")
inline octave_value_list
F__expint__ (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::F__expint__ (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::F__fieldnames__' instead")
inline octave_value_list
F__fieldnames__ (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::F__fieldnames__ (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::F__fnmatch__' instead")
inline octave_value_list
F__fnmatch__ (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::F__fnmatch__ (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::F__gammainc__' instead")
inline octave_value_list
F__gammainc__ (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::F__gammainc__ (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::F__get_system_fonts__' instead")
inline octave_value_list
F__get_system_fonts__ (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::F__get_system_fonts__ (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::F__ichol0__' instead")
inline octave_value_list
F__ichol0__ (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::F__ichol0__ (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::F__icholt__' instead")
inline octave_value_list
F__icholt__ (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::F__icholt__ (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::F__ilu0__' instead")
inline octave_value_list
F__ilu0__ (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::F__ilu0__ (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::F__iluc__' instead")
inline octave_value_list
F__iluc__ (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::F__iluc__ (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::F__ilutp__' instead")
inline octave_value_list
F__ilutp__ (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::F__ilutp__ (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::F__inline_ctor__' instead")
inline octave_value_list
F__inline_ctor__ (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::F__inline_ctor__ (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::F__is_elevated_process__' instead")
inline octave_value_list
F__is_elevated_process__ (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::F__is_elevated_process__ (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::F__is_handle_visible__' instead")
inline octave_value_list
F__is_handle_visible__ (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::F__is_handle_visible__ (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::F__isprimelarge__' instead")
inline octave_value_list
F__isprimelarge__ (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::F__isprimelarge__ (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::F__java2mat__' instead")
inline octave_value_list
F__java2mat__ (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::F__java2mat__ (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::F__java_exit__' instead")
inline octave_value_list
F__java_exit__ (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::F__java_exit__ (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::F__java_get__' instead")
inline octave_value_list
F__java_get__ (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::F__java_get__ (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::F__java_init__' instead")
inline octave_value_list
F__java_init__ (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::F__java_init__ (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::F__java_set__' instead")
inline octave_value_list
F__java_set__ (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::F__java_set__ (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::F__lapack_version__' instead")
inline octave_value_list
F__lapack_version__ (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::F__lapack_version__ (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::F__lin_interpn__' instead")
inline octave_value_list
F__lin_interpn__ (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::F__lin_interpn__ (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::F__locale_charset__' instead")
inline octave_value_list
F__locale_charset__ (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::F__locale_charset__ (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::F__magick_finfo__' instead")
inline octave_value_list
F__magick_finfo__ (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::F__magick_finfo__ (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::F__magick_formats__' instead")
inline octave_value_list
F__magick_formats__ (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::F__magick_formats__ (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::F__magick_ping__' instead")
inline octave_value_list
F__magick_ping__ (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::F__magick_ping__ (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::F__magick_read__' instead")
inline octave_value_list
F__magick_read__ (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::F__magick_read__ (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::F__magick_write__' instead")
inline octave_value_list
F__magick_write__ (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::F__magick_write__ (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::F__make_valid_name__' instead")
inline octave_value_list
F__make_valid_name__ (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::F__make_valid_name__ (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::F__meta_get_package__' instead")
inline octave_value_list
F__meta_get_package__ (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::F__meta_get_package__ (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::F__mkdir__' instead")
inline octave_value_list
F__mkdir__ (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::F__mkdir__ (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::F__native2unicode__' instead")
inline octave_value_list
F__native2unicode__ (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::F__native2unicode__ (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::F__octave_config_info__' instead")
inline octave_value_list
F__octave_config_info__ (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::F__octave_config_info__ (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::F__open_with_system_app__' instead")
inline octave_value_list
F__open_with_system_app__ (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::F__open_with_system_app__ (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::F__operators__' instead")
inline octave_value_list
F__operators__ (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::F__operators__ (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::F__parent_classes__' instead")
inline octave_value_list
F__parent_classes__ (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::F__parent_classes__ (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::F__parser_debug_flag__' instead")
inline octave_value_list
F__parser_debug_flag__ (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::F__parser_debug_flag__ (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::F__pchip_deriv__' instead")
inline octave_value_list
F__pchip_deriv__ (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::F__pchip_deriv__ (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::F__qp__' instead")
inline octave_value_list
F__qp__ (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::F__qp__ (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::F__restful_service__' instead")
inline octave_value_list
F__restful_service__ (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::F__restful_service__ (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::F__sort_rows_idx__' instead")
inline octave_value_list
F__sort_rows_idx__ (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::F__sort_rows_idx__ (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::F__streameuler2d__' instead")
inline octave_value_list
F__streameuler2d__ (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::F__streameuler2d__ (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::F__streameuler3d__' instead")
inline octave_value_list
F__streameuler3d__ (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::F__streameuler3d__ (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::F__u8_validate__' instead")
inline octave_value_list
F__u8_validate__ (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::F__u8_validate__ (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::F__unicode2native__' instead")
inline octave_value_list
F__unicode2native__ (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::F__unicode2native__ (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::F__unicode_length__' instead")
inline octave_value_list
F__unicode_length__ (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::F__unicode_length__ (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::F__version_info__' instead")
inline octave_value_list
F__version_info__ (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::F__version_info__ (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::F__wglob__' instead")
inline octave_value_list
F__wglob__ (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::F__wglob__ (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::F__wmemory__' instead")
inline octave_value_list
F__wmemory__ (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::F__wmemory__ (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fabs' instead")
inline octave_value_list
Fabs (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fabs (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Facos' instead")
inline octave_value_list
Facos (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Facos (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Facosh' instead")
inline octave_value_list
Facosh (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Facosh (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fairy' instead")
inline octave_value_list
Fairy (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fairy (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fall' instead")
inline octave_value_list
Fall (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fall (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Famd' instead")
inline octave_value_list
Famd (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Famd (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fand' instead")
inline octave_value_list
Fand (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fand (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fangle' instead")
inline octave_value_list
Fangle (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fangle (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fany' instead")
inline octave_value_list
Fany (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fany (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Farg' instead")
inline octave_value_list
Farg (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Farg (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fargv' instead")
inline octave_value_list
Fargv (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fargv (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fasin' instead")
inline octave_value_list
Fasin (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fasin (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fasinh' instead")
inline octave_value_list
Fasinh (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fasinh (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fatan' instead")
inline octave_value_list
Fatan (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fatan (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fatan2' instead")
inline octave_value_list
Fatan2 (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fatan2 (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fatanh' instead")
inline octave_value_list
Fatanh (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fatanh (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fbalance' instead")
inline octave_value_list
Fbalance (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fbalance (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fbase64_decode' instead")
inline octave_value_list
Fbase64_decode (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fbase64_decode (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fbase64_encode' instead")
inline octave_value_list
Fbase64_encode (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fbase64_encode (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fbesselh' instead")
inline octave_value_list
Fbesselh (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fbesselh (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fbesseli' instead")
inline octave_value_list
Fbesseli (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fbesseli (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fbesselj' instead")
inline octave_value_list
Fbesselj (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fbesselj (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fbesselk' instead")
inline octave_value_list
Fbesselk (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fbesselk (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fbessely' instead")
inline octave_value_list
Fbessely (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fbessely (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fbitand' instead")
inline octave_value_list
Fbitand (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fbitand (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fbitor' instead")
inline octave_value_list
Fbitor (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fbitor (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fbitpack' instead")
inline octave_value_list
Fbitpack (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fbitpack (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fbitshift' instead")
inline octave_value_list
Fbitshift (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fbitshift (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fbitunpack' instead")
inline octave_value_list
Fbitunpack (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fbitunpack (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fbitxor' instead")
inline octave_value_list
Fbitxor (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fbitxor (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fblkmm' instead")
inline octave_value_list
Fblkmm (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fblkmm (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fcanonicalize_file_name' instead")
inline octave_value_list
Fcanonicalize_file_name (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fcanonicalize_file_name (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fcat' instead")
inline octave_value_list
Fcat (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fcat (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fcbrt' instead")
inline octave_value_list
Fcbrt (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fcbrt (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fccolamd' instead")
inline octave_value_list
Fccolamd (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fccolamd (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fceil' instead")
inline octave_value_list
Fceil (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fceil (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fcell' instead")
inline octave_value_list
Fcell (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fcell (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fcell2struct' instead")
inline octave_value_list
Fcell2struct (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fcell2struct (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fcellindexmat' instead")
inline octave_value_list
Fcellindexmat (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fcellindexmat (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fcellslices' instead")
inline octave_value_list
Fcellslices (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fcellslices (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fcellstr' instead")
inline octave_value_list
Fcellstr (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fcellstr (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fchar' instead")
inline octave_value_list
Fchar (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fchar (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fchol' instead")
inline octave_value_list
Fchol (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fchol (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fchol2inv' instead")
inline octave_value_list
Fchol2inv (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fchol2inv (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fcholdelete' instead")
inline octave_value_list
Fcholdelete (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fcholdelete (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fcholinsert' instead")
inline octave_value_list
Fcholinsert (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fcholinsert (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fcholinv' instead")
inline octave_value_list
Fcholinv (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fcholinv (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fcholshift' instead")
inline octave_value_list
Fcholshift (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fcholshift (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fcholupdate' instead")
inline octave_value_list
Fcholupdate (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fcholupdate (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fclc' instead")
inline octave_value_list
Fclc (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fclc (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fcmdline_options' instead")
inline octave_value_list
Fcmdline_options (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fcmdline_options (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fcolamd' instead")
inline octave_value_list
Fcolamd (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fcolamd (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fcolloc' instead")
inline octave_value_list
Fcolloc (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fcolloc (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fcolon' instead")
inline octave_value_list
Fcolon (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fcolon (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fcolumns' instead")
inline octave_value_list
Fcolumns (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fcolumns (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fcompletion_matches' instead")
inline octave_value_list
Fcompletion_matches (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fcompletion_matches (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fcomplex' instead")
inline octave_value_list
Fcomplex (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fcomplex (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fconfirm_recursive_rmdir' instead")
inline octave_value_list
Fconfirm_recursive_rmdir (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fconfirm_recursive_rmdir (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fconj' instead")
inline octave_value_list
Fconj (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fconj (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fconv2' instead")
inline octave_value_list
Fconv2 (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fconv2 (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fconvn' instead")
inline octave_value_list
Fconvn (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fconvn (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fcos' instead")
inline octave_value_list
Fcos (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fcos (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fcosh' instead")
inline octave_value_list
Fcosh (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fcosh (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fcputime' instead")
inline octave_value_list
Fcputime (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fcputime (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fcsymamd' instead")
inline octave_value_list
Fcsymamd (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fcsymamd (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fctranspose' instead")
inline octave_value_list
Fctranspose (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fctranspose (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fcummax' instead")
inline octave_value_list
Fcummax (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fcummax (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fcummin' instead")
inline octave_value_list
Fcummin (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fcummin (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fcumprod' instead")
inline octave_value_list
Fcumprod (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fcumprod (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fcumsum' instead")
inline octave_value_list
Fcumsum (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fcumsum (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fdaspk_options' instead")
inline octave_value_list
Fdaspk_options (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fdaspk_options (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fdasrt_options' instead")
inline octave_value_list
Fdasrt_options (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fdasrt_options (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fdassl_options' instead")
inline octave_value_list
Fdassl_options (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fdassl_options (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fdawson' instead")
inline octave_value_list
Fdawson (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fdawson (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fdebug_java' instead")
inline octave_value_list
Fdebug_java (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fdebug_java (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fdebug_on_interrupt' instead")
inline octave_value_list
Fdebug_on_interrupt (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fdebug_on_interrupt (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fdet' instead")
inline octave_value_list
Fdet (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fdet (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fdiag' instead")
inline octave_value_list
Fdiag (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fdiag (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fdiff' instead")
inline octave_value_list
Fdiff (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fdiff (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fdisp' instead")
inline octave_value_list
Fdisp (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fdisp (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fdisplay' instead")
inline octave_value_list
Fdisplay (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fdisplay (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fdmperm' instead")
inline octave_value_list
Fdmperm (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fdmperm (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fdo_string_escapes' instead")
inline octave_value_list
Fdo_string_escapes (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fdo_string_escapes (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fdot' instead")
inline octave_value_list
Fdot (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fdot (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fdouble' instead")
inline octave_value_list
Fdouble (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fdouble (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fe' instead")
inline octave_value_list
Fe (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fe (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Feig' instead")
inline octave_value_list
Feig (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Feig (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fellipj' instead")
inline octave_value_list
Fellipj (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fellipj (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fendgrent' instead")
inline octave_value_list
Fendgrent (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fendgrent (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fendpwent' instead")
inline octave_value_list
Fendpwent (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fendpwent (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Feps' instead")
inline octave_value_list
Feps (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Feps (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Feq' instead")
inline octave_value_list
Feq (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Feq (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Ferf' instead")
inline octave_value_list
Ferf (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Ferf (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Ferfc' instead")
inline octave_value_list
Ferfc (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Ferfc (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Ferfcinv' instead")
inline octave_value_list
Ferfcinv (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Ferfcinv (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Ferfcx' instead")
inline octave_value_list
Ferfcx (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Ferfcx (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Ferfi' instead")
inline octave_value_list
Ferfi (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Ferfi (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Ferfinv' instead")
inline octave_value_list
Ferfinv (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Ferfinv (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Ferrno' instead")
inline octave_value_list
Ferrno (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Ferrno (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Ferrno_list' instead")
inline octave_value_list
Ferrno_list (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Ferrno_list (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fetree' instead")
inline octave_value_list
Fetree (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fetree (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fexp' instead")
inline octave_value_list
Fexp (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fexp (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fexpm1' instead")
inline octave_value_list
Fexpm1 (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fexpm1 (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Feye' instead")
inline octave_value_list
Feye (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Feye (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Ffalse' instead")
inline octave_value_list
Ffalse (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Ffalse (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Ffft' instead")
inline octave_value_list
Ffft (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Ffft (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Ffft2' instead")
inline octave_value_list
Ffft2 (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Ffft2 (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Ffftn' instead")
inline octave_value_list
Ffftn (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Ffftn (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Ffile_in_path' instead")
inline octave_value_list
Ffile_in_path (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Ffile_in_path (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Ffilesep' instead")
inline octave_value_list
Ffilesep (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Ffilesep (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Ffilter' instead")
inline octave_value_list
Ffilter (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Ffilter (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Ffind' instead")
inline octave_value_list
Ffind (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Ffind (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Ffix' instead")
inline octave_value_list
Ffix (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Ffix (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Ffixed_point_format' instead")
inline octave_value_list
Ffixed_point_format (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Ffixed_point_format (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fflintmax' instead")
inline octave_value_list
Fflintmax (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fflintmax (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Ffloor' instead")
inline octave_value_list
Ffloor (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Ffloor (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fformat' instead")
inline octave_value_list
Fformat (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fformat (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Ffull' instead")
inline octave_value_list
Ffull (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Ffull (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Ffunc2str' instead")
inline octave_value_list
Ffunc2str (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Ffunc2str (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Ffunctions' instead")
inline octave_value_list
Ffunctions (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Ffunctions (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fgamma' instead")
inline octave_value_list
Fgamma (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fgamma (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fgcd' instead")
inline octave_value_list
Fgcd (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fgcd (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fge' instead")
inline octave_value_list
Fge (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fge (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fgenpath' instead")
inline octave_value_list
Fgenpath (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fgenpath (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fget_home_directory' instead")
inline octave_value_list
Fget_home_directory (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fget_home_directory (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fgetegid' instead")
inline octave_value_list
Fgetegid (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fgetegid (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fgetenv' instead")
inline octave_value_list
Fgetenv (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fgetenv (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fgeteuid' instead")
inline octave_value_list
Fgeteuid (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fgeteuid (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fgetgid' instead")
inline octave_value_list
Fgetgid (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fgetgid (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fgetgrent' instead")
inline octave_value_list
Fgetgrent (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fgetgrent (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fgetgrgid' instead")
inline octave_value_list
Fgetgrgid (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fgetgrgid (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fgetgrnam' instead")
inline octave_value_list
Fgetgrnam (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fgetgrnam (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fgethostname' instead")
inline octave_value_list
Fgethostname (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fgethostname (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fgetpgrp' instead")
inline octave_value_list
Fgetpgrp (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fgetpgrp (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fgetpid' instead")
inline octave_value_list
Fgetpid (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fgetpid (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fgetppid' instead")
inline octave_value_list
Fgetppid (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fgetppid (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fgetpwent' instead")
inline octave_value_list
Fgetpwent (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fgetpwent (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fgetpwnam' instead")
inline octave_value_list
Fgetpwnam (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fgetpwnam (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fgetpwuid' instead")
inline octave_value_list
Fgetpwuid (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fgetpwuid (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fgetrusage' instead")
inline octave_value_list
Fgetrusage (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fgetrusage (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fgetuid' instead")
inline octave_value_list
Fgetuid (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fgetuid (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fgivens' instead")
inline octave_value_list
Fgivens (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fgivens (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fglob' instead")
inline octave_value_list
Fglob (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fglob (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fgmtime' instead")
inline octave_value_list
Fgmtime (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fgmtime (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fgsvd' instead")
inline octave_value_list
Fgsvd (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fgsvd (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fgt' instead")
inline octave_value_list
Fgt (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fgt (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fhash' instead")
inline octave_value_list
Fhash (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fhash (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fhess' instead")
inline octave_value_list
Fhess (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fhess (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fhex2num' instead")
inline octave_value_list
Fhex2num (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fhex2num (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fhistory_control' instead")
inline octave_value_list
Fhistory_control (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fhistory_control (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fhistory_file' instead")
inline octave_value_list
Fhistory_file (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fhistory_file (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fhistory_save' instead")
inline octave_value_list
Fhistory_save (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fhistory_save (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fhistory_size' instead")
inline octave_value_list
Fhistory_size (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fhistory_size (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fhorzcat' instead")
inline octave_value_list
Fhorzcat (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fhorzcat (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fhypot' instead")
inline octave_value_list
Fhypot (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fhypot (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fifft' instead")
inline octave_value_list
Fifft (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fifft (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fifft2' instead")
inline octave_value_list
Fifft2 (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fifft2 (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fifftn' instead")
inline octave_value_list
Fifftn (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fifftn (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fignore_function_time_stamp' instead")
inline octave_value_list
Fignore_function_time_stamp (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fignore_function_time_stamp (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fimag' instead")
inline octave_value_list
Fimag (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fimag (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Find2sub' instead")
inline octave_value_list
Find2sub (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Find2sub (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fint16' instead")
inline octave_value_list
Fint16 (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fint16 (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fint32' instead")
inline octave_value_list
Fint32 (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fint32 (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fint64' instead")
inline octave_value_list
Fint64 (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fint64 (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fint8' instead")
inline octave_value_list
Fint8 (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fint8 (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fintmax' instead")
inline octave_value_list
Fintmax (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fintmax (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fintmin' instead")
inline octave_value_list
Fintmin (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fintmin (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Finv' instead")
inline octave_value_list
Finv (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Finv (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fipermute' instead")
inline octave_value_list
Fipermute (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fipermute (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fis_absolute_filename' instead")
inline octave_value_list
Fis_absolute_filename (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fis_absolute_filename (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fis_dq_string' instead")
inline octave_value_list
Fis_dq_string (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fis_dq_string (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fis_function_handle' instead")
inline octave_value_list
Fis_function_handle (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fis_function_handle (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fis_rooted_relative_filename' instead")
inline octave_value_list
Fis_rooted_relative_filename (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fis_rooted_relative_filename (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fis_same_file' instead")
inline octave_value_list
Fis_same_file (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fis_same_file (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fis_sq_string' instead")
inline octave_value_list
Fis_sq_string (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fis_sq_string (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fisa' instead")
inline octave_value_list
Fisa (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fisa (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fisalnum' instead")
inline octave_value_list
Fisalnum (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fisalnum (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fisalpha' instead")
inline octave_value_list
Fisalpha (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fisalpha (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fisascii' instead")
inline octave_value_list
Fisascii (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fisascii (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fiscell' instead")
inline octave_value_list
Fiscell (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fiscell (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fiscellstr' instead")
inline octave_value_list
Fiscellstr (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fiscellstr (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fischar' instead")
inline octave_value_list
Fischar (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fischar (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fiscntrl' instead")
inline octave_value_list
Fiscntrl (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fiscntrl (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fiscolumn' instead")
inline octave_value_list
Fiscolumn (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fiscolumn (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fiscomplex' instead")
inline octave_value_list
Fiscomplex (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fiscomplex (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fisdigit' instead")
inline octave_value_list
Fisdigit (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fisdigit (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fisempty' instead")
inline octave_value_list
Fisempty (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fisempty (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fisfield' instead")
inline octave_value_list
Fisfield (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fisfield (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fisfinite' instead")
inline octave_value_list
Fisfinite (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fisfinite (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fisfloat' instead")
inline octave_value_list
Fisfloat (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fisfloat (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fisgraph' instead")
inline octave_value_list
Fisgraph (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fisgraph (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fisguirunning' instead")
inline octave_value_list
Fisguirunning (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fisguirunning (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fisieee' instead")
inline octave_value_list
Fisieee (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fisieee (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fisinf' instead")
inline octave_value_list
Fisinf (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fisinf (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fisinteger' instead")
inline octave_value_list
Fisinteger (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fisinteger (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fisjava' instead")
inline octave_value_list
Fisjava (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fisjava (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fiskeyword' instead")
inline octave_value_list
Fiskeyword (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fiskeyword (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fislogical' instead")
inline octave_value_list
Fislogical (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fislogical (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fislower' instead")
inline octave_value_list
Fislower (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fislower (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fismatrix' instead")
inline octave_value_list
Fismatrix (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fismatrix (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fisna' instead")
inline octave_value_list
Fisna (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fisna (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fisnan' instead")
inline octave_value_list
Fisnan (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fisnan (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fisnull' instead")
inline octave_value_list
Fisnull (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fisnull (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fisnumeric' instead")
inline octave_value_list
Fisnumeric (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fisnumeric (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fisobject' instead")
inline octave_value_list
Fisobject (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fisobject (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fisprint' instead")
inline octave_value_list
Fisprint (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fisprint (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fispunct' instead")
inline octave_value_list
Fispunct (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fispunct (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fisreal' instead")
inline octave_value_list
Fisreal (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fisreal (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fisrow' instead")
inline octave_value_list
Fisrow (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fisrow (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fisscalar' instead")
inline octave_value_list
Fisscalar (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fisscalar (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fissorted' instead")
inline octave_value_list
Fissorted (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fissorted (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fisspace' instead")
inline octave_value_list
Fisspace (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fisspace (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fissparse' instead")
inline octave_value_list
Fissparse (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fissparse (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fissquare' instead")
inline octave_value_list
Fissquare (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fissquare (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fisstruct' instead")
inline octave_value_list
Fisstruct (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fisstruct (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fisstudent' instead")
inline octave_value_list
Fisstudent (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fisstudent (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fisupper' instead")
inline octave_value_list
Fisupper (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fisupper (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fisvarname' instead")
inline octave_value_list
Fisvarname (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fisvarname (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fisvector' instead")
inline octave_value_list
Fisvector (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fisvector (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fisxdigit' instead")
inline octave_value_list
Fisxdigit (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fisxdigit (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::FjavaMethod' instead")
inline octave_value_list
FjavaMethod (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::FjavaMethod (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::FjavaObject' instead")
inline octave_value_list
FjavaObject (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::FjavaObject (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fjava_matrix_autoconversion' instead")
inline octave_value_list
Fjava_matrix_autoconversion (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fjava_matrix_autoconversion (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fjava_unsigned_autoconversion' instead")
inline octave_value_list
Fjava_unsigned_autoconversion (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fjava_unsigned_autoconversion (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fjsondecode' instead")
inline octave_value_list
Fjsondecode (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fjsondecode (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fjsonencode' instead")
inline octave_value_list
Fjsonencode (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fjsonencode (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fkill' instead")
inline octave_value_list
Fkill (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fkill (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fkron' instead")
inline octave_value_list
Fkron (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fkron (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fldivide' instead")
inline octave_value_list
Fldivide (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fldivide (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fle' instead")
inline octave_value_list
Fle (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fle (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Flength' instead")
inline octave_value_list
Flength (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Flength (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Flgamma' instead")
inline octave_value_list
Flgamma (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Flgamma (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Flink' instead")
inline octave_value_list
Flink (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Flink (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Flinspace' instead")
inline octave_value_list
Flinspace (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Flinspace (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Flist_in_columns' instead")
inline octave_value_list
Flist_in_columns (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Flist_in_columns (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Flocaltime' instead")
inline octave_value_list
Flocaltime (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Flocaltime (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Flog' instead")
inline octave_value_list
Flog (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Flog (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Flog10' instead")
inline octave_value_list
Flog10 (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Flog10 (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Flog1p' instead")
inline octave_value_list
Flog1p (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Flog1p (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Flog2' instead")
inline octave_value_list
Flog2 (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Flog2 (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Flogical' instead")
inline octave_value_list
Flogical (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Flogical (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Flookup' instead")
inline octave_value_list
Flookup (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Flookup (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Flsode_options' instead")
inline octave_value_list
Flsode_options (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Flsode_options (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Flstat' instead")
inline octave_value_list
Flstat (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Flstat (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Flt' instead")
inline octave_value_list
Flt (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Flt (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Flu' instead")
inline octave_value_list
Flu (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Flu (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fluupdate' instead")
inline octave_value_list
Fluupdate (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fluupdate (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fmake_absolute_filename' instead")
inline octave_value_list
Fmake_absolute_filename (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fmake_absolute_filename (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fmat2cell' instead")
inline octave_value_list
Fmat2cell (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fmat2cell (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fmatrix_type' instead")
inline octave_value_list
Fmatrix_type (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fmatrix_type (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fmax' instead")
inline octave_value_list
Fmax (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fmax (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fmerge' instead")
inline octave_value_list
Fmerge (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fmerge (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fmetaclass' instead")
inline octave_value_list
Fmetaclass (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fmetaclass (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fmgorth' instead")
inline octave_value_list
Fmgorth (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fmgorth (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fmin' instead")
inline octave_value_list
Fmin (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fmin (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fminus' instead")
inline octave_value_list
Fminus (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fminus (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fmissing_component_hook' instead")
inline octave_value_list
Fmissing_component_hook (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fmissing_component_hook (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fmissing_function_hook' instead")
inline octave_value_list
Fmissing_function_hook (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fmissing_function_hook (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fmkfifo' instead")
inline octave_value_list
Fmkfifo (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fmkfifo (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fmktime' instead")
inline octave_value_list
Fmktime (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fmktime (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fmldivide' instead")
inline octave_value_list
Fmldivide (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fmldivide (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fmod' instead")
inline octave_value_list
Fmod (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fmod (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fmpower' instead")
inline octave_value_list
Fmpower (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fmpower (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fmrdivide' instead")
inline octave_value_list
Fmrdivide (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fmrdivide (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fmtimes' instead")
inline octave_value_list
Fmtimes (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fmtimes (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fnative_float_format' instead")
inline octave_value_list
Fnative_float_format (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fnative_float_format (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fndims' instead")
inline octave_value_list
Fndims (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fndims (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fne' instead")
inline octave_value_list
Fne (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fne (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fnewline' instead")
inline octave_value_list
Fnewline (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fnewline (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fnnz' instead")
inline octave_value_list
Fnnz (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fnnz (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fnorm' instead")
inline octave_value_list
Fnorm (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fnorm (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fnot' instead")
inline octave_value_list
Fnot (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fnot (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fnproc' instead")
inline octave_value_list
Fnproc (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fnproc (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fnth_element' instead")
inline octave_value_list
Fnth_element (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fnth_element (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fnum2cell' instead")
inline octave_value_list
Fnum2cell (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fnum2cell (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fnum2hex' instead")
inline octave_value_list
Fnum2hex (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fnum2hex (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fnumel' instead")
inline octave_value_list
Fnumel (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fnumel (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fnumfields' instead")
inline octave_value_list
Fnumfields (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fnumfields (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fnzmax' instead")
inline octave_value_list
Fnzmax (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fnzmax (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::FonCleanup' instead")
inline octave_value_list
FonCleanup (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::FonCleanup (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fones' instead")
inline octave_value_list
Fones (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fones (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Foptimize_diagonal_matrix' instead")
inline octave_value_list
Foptimize_diagonal_matrix (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Foptimize_diagonal_matrix (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Foptimize_permutation_matrix' instead")
inline octave_value_list
Foptimize_permutation_matrix (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Foptimize_permutation_matrix (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Foptimize_range' instead")
inline octave_value_list
Foptimize_range (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Foptimize_range (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Foptimize_subsasgn_calls' instead")
inline octave_value_list
Foptimize_subsasgn_calls (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Foptimize_subsasgn_calls (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::For' instead")
inline octave_value_list
For (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::For (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fordqz' instead")
inline octave_value_list
Fordqz (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fordqz (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fordschur' instead")
inline octave_value_list
Fordschur (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fordschur (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Foutput_precision' instead")
inline octave_value_list
Foutput_precision (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Foutput_precision (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fpathsep' instead")
inline octave_value_list
Fpathsep (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fpathsep (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fpermute' instead")
inline octave_value_list
Fpermute (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fpermute (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fpi' instead")
inline octave_value_list
Fpi (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fpi (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fpinv' instead")
inline octave_value_list
Fpinv (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fpinv (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fplus' instead")
inline octave_value_list
Fplus (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fplus (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fpower' instead")
inline octave_value_list
Fpower (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fpower (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fprint_empty_dimensions' instead")
inline octave_value_list
Fprint_empty_dimensions (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fprint_empty_dimensions (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fprint_struct_array_contents' instead")
inline octave_value_list
Fprint_struct_array_contents (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fprint_struct_array_contents (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fprod' instead")
inline octave_value_list
Fprod (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fprod (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fprogram_invocation_name' instead")
inline octave_value_list
Fprogram_invocation_name (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fprogram_invocation_name (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fprogram_name' instead")
inline octave_value_list
Fprogram_name (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fprogram_name (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fproperties' instead")
inline octave_value_list
Fproperties (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fproperties (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fpsi' instead")
inline octave_value_list
Fpsi (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fpsi (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fpwd' instead")
inline octave_value_list
Fpwd (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fpwd (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fqr' instead")
inline octave_value_list
Fqr (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fqr (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fqrdelete' instead")
inline octave_value_list
Fqrdelete (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fqrdelete (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fqrinsert' instead")
inline octave_value_list
Fqrinsert (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fqrinsert (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fqrshift' instead")
inline octave_value_list
Fqrshift (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fqrshift (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fqrupdate' instead")
inline octave_value_list
Fqrupdate (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fqrupdate (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fquad_options' instead")
inline octave_value_list
Fquad_options (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fquad_options (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fqz' instead")
inline octave_value_list
Fqz (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fqz (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Frand' instead")
inline octave_value_list
Frand (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Frand (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Frande' instead")
inline octave_value_list
Frande (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Frande (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Frandg' instead")
inline octave_value_list
Frandg (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Frandg (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Frandn' instead")
inline octave_value_list
Frandn (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Frandn (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Frandp' instead")
inline octave_value_list
Frandp (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Frandp (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Frandperm' instead")
inline octave_value_list
Frandperm (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Frandperm (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Frats' instead")
inline octave_value_list
Frats (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Frats (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Frcond' instead")
inline octave_value_list
Frcond (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Frcond (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Frdivide' instead")
inline octave_value_list
Frdivide (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Frdivide (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Freaddir' instead")
inline octave_value_list
Freaddir (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Freaddir (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Freadline_re_read_init_file' instead")
inline octave_value_list
Freadline_re_read_init_file (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Freadline_re_read_init_file (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Freadline_read_init_file' instead")
inline octave_value_list
Freadline_read_init_file (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Freadline_read_init_file (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Freadlink' instead")
inline octave_value_list
Freadlink (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Freadlink (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Freal' instead")
inline octave_value_list
Freal (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Freal (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Frealmax' instead")
inline octave_value_list
Frealmax (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Frealmax (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Frealmin' instead")
inline octave_value_list
Frealmin (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Frealmin (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fregexp' instead")
inline octave_value_list
Fregexp (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fregexp (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fregexpi' instead")
inline octave_value_list
Fregexpi (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fregexpi (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fregexprep' instead")
inline octave_value_list
Fregexprep (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fregexprep (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Frehash' instead")
inline octave_value_list
Frehash (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Frehash (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Frem' instead")
inline octave_value_list
Frem (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Frem (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Frepelems' instead")
inline octave_value_list
Frepelems (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Frepelems (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Freshape' instead")
inline octave_value_list
Freshape (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Freshape (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fresize' instead")
inline octave_value_list
Fresize (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fresize (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Frmfield' instead")
inline octave_value_list
Frmfield (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Frmfield (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fround' instead")
inline octave_value_list
Fround (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fround (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Froundb' instead")
inline octave_value_list
Froundb (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Froundb (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Frows' instead")
inline octave_value_list
Frows (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Frows (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Frsf2csf' instead")
inline octave_value_list
Frsf2csf (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Frsf2csf (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fsave_precision' instead")
inline octave_value_list
Fsave_precision (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fsave_precision (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fschur' instead")
inline octave_value_list
Fschur (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fschur (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fsetenv' instead")
inline octave_value_list
Fsetenv (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fsetenv (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fsetgrent' instead")
inline octave_value_list
Fsetgrent (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fsetgrent (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fsetpwent' instead")
inline octave_value_list
Fsetpwent (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fsetpwent (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fsighup_dumps_octave_core' instead")
inline octave_value_list
Fsighup_dumps_octave_core (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fsighup_dumps_octave_core (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fsign' instead")
inline octave_value_list
Fsign (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fsign (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fsignbit' instead")
inline octave_value_list
Fsignbit (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fsignbit (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fsigquit_dumps_octave_core' instead")
inline octave_value_list
Fsigquit_dumps_octave_core (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fsigquit_dumps_octave_core (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fsigterm_dumps_octave_core' instead")
inline octave_value_list
Fsigterm_dumps_octave_core (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fsigterm_dumps_octave_core (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fsin' instead")
inline octave_value_list
Fsin (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fsin (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fsingle' instead")
inline octave_value_list
Fsingle (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fsingle (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fsinh' instead")
inline octave_value_list
Fsinh (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fsinh (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fsize' instead")
inline octave_value_list
Fsize (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fsize (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fsize_equal' instead")
inline octave_value_list
Fsize_equal (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fsize_equal (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fsizemax' instead")
inline octave_value_list
Fsizemax (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fsizemax (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fsizeof' instead")
inline octave_value_list
Fsizeof (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fsizeof (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fsort' instead")
inline octave_value_list
Fsort (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fsort (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fspalloc' instead")
inline octave_value_list
Fspalloc (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fspalloc (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fsparse' instead")
inline octave_value_list
Fsparse (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fsparse (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fsparse_auto_mutate' instead")
inline octave_value_list
Fsparse_auto_mutate (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fsparse_auto_mutate (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fsplit_long_rows' instead")
inline octave_value_list
Fsplit_long_rows (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fsplit_long_rows (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fspparms' instead")
inline octave_value_list
Fspparms (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fspparms (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fsprank' instead")
inline octave_value_list
Fsprank (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fsprank (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fsprintf' instead")
inline octave_value_list
Fsprintf (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fsprintf (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fsqrt' instead")
inline octave_value_list
Fsqrt (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fsqrt (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fsqrtm' instead")
inline octave_value_list
Fsqrtm (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fsqrtm (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fsqueeze' instead")
inline octave_value_list
Fsqueeze (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fsqueeze (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fsscanf' instead")
inline octave_value_list
Fsscanf (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fsscanf (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fstr2double' instead")
inline octave_value_list
Fstr2double (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fstr2double (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fstrcmp' instead")
inline octave_value_list
Fstrcmp (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fstrcmp (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fstrcmpi' instead")
inline octave_value_list
Fstrcmpi (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fstrcmpi (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fstrfind' instead")
inline octave_value_list
Fstrfind (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fstrfind (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fstrftime' instead")
inline octave_value_list
Fstrftime (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fstrftime (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fstrncmp' instead")
inline octave_value_list
Fstrncmp (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fstrncmp (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fstrncmpi' instead")
inline octave_value_list
Fstrncmpi (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fstrncmpi (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fstrptime' instead")
inline octave_value_list
Fstrptime (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fstrptime (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fstrrep' instead")
inline octave_value_list
Fstrrep (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fstrrep (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fstruct' instead")
inline octave_value_list
Fstruct (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fstruct (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fstruct2cell' instead")
inline octave_value_list
Fstruct2cell (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fstruct2cell (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fstruct_levels_to_print' instead")
inline octave_value_list
Fstruct_levels_to_print (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fstruct_levels_to_print (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fstrvcat' instead")
inline octave_value_list
Fstrvcat (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fstrvcat (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fsub2ind' instead")
inline octave_value_list
Fsub2ind (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fsub2ind (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fsubsasgn' instead")
inline octave_value_list
Fsubsasgn (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fsubsasgn (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fsubsref' instead")
inline octave_value_list
Fsubsref (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fsubsref (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fsum' instead")
inline octave_value_list
Fsum (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fsum (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fsumsq' instead")
inline octave_value_list
Fsumsq (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fsumsq (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fsvd' instead")
inline octave_value_list
Fsvd (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fsvd (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fsvd_driver' instead")
inline octave_value_list
Fsvd_driver (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fsvd_driver (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fsylvester' instead")
inline octave_value_list
Fsylvester (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fsylvester (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fsymamd' instead")
inline octave_value_list
Fsymamd (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fsymamd (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fsymbfact' instead")
inline octave_value_list
Fsymbfact (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fsymbfact (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fsymlink' instead")
inline octave_value_list
Fsymlink (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fsymlink (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fsymrcm' instead")
inline octave_value_list
Fsymrcm (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fsymrcm (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fsystem' instead")
inline octave_value_list
Fsystem (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fsystem (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Ftan' instead")
inline octave_value_list
Ftan (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Ftan (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Ftanh' instead")
inline octave_value_list
Ftanh (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Ftanh (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Ftempname' instead")
inline octave_value_list
Ftempname (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Ftempname (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fterminal_size' instead")
inline octave_value_list
Fterminal_size (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fterminal_size (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Ftic' instead")
inline octave_value_list
Ftic (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Ftic (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Ftilde_expand' instead")
inline octave_value_list
Ftilde_expand (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Ftilde_expand (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Ftime' instead")
inline octave_value_list
Ftime (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Ftime (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Ftimes' instead")
inline octave_value_list
Ftimes (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Ftimes (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Ftoc' instead")
inline octave_value_list
Ftoc (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Ftoc (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Ftolower' instead")
inline octave_value_list
Ftolower (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Ftolower (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Ftoupper' instead")
inline octave_value_list
Ftoupper (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Ftoupper (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Ftranspose' instead")
inline octave_value_list
Ftranspose (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Ftranspose (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Ftril' instead")
inline octave_value_list
Ftril (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Ftril (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Ftriu' instead")
inline octave_value_list
Ftriu (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Ftriu (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Ftrue' instead")
inline octave_value_list
Ftrue (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Ftrue (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Ftsearch' instead")
inline octave_value_list
Ftsearch (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Ftsearch (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Ftypecast' instead")
inline octave_value_list
Ftypecast (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Ftypecast (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fuint16' instead")
inline octave_value_list
Fuint16 (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fuint16 (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fuint32' instead")
inline octave_value_list
Fuint32 (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fuint32 (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fuint64' instead")
inline octave_value_list
Fuint64 (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fuint64 (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fuint8' instead")
inline octave_value_list
Fuint8 (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fuint8 (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fumask' instead")
inline octave_value_list
Fumask (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fumask (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fuminus' instead")
inline octave_value_list
Fuminus (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fuminus (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Funame' instead")
inline octave_value_list
Funame (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Funame (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fundo_string_escapes' instead")
inline octave_value_list
Fundo_string_escapes (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fundo_string_escapes (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Funicode_idx' instead")
inline octave_value_list
Funicode_idx (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Funicode_idx (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Funsetenv' instead")
inline octave_value_list
Funsetenv (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Funsetenv (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fuplus' instead")
inline octave_value_list
Fuplus (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fuplus (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Furlread' instead")
inline octave_value_list
Furlread (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Furlread (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Furlwrite' instead")
inline octave_value_list
Furlwrite (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Furlwrite (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fuser_config_dir' instead")
inline octave_value_list
Fuser_config_dir (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fuser_config_dir (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fuser_data_dir' instead")
inline octave_value_list
Fuser_data_dir (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fuser_data_dir (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fvec' instead")
inline octave_value_list
Fvec (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fvec (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fvertcat' instead")
inline octave_value_list
Fvertcat (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fvertcat (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fwaitpid' instead")
inline octave_value_list
Fwaitpid (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fwaitpid (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fwarranty' instead")
inline octave_value_list
Fwarranty (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fwarranty (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fwinqueryreg' instead")
inline octave_value_list
Fwinqueryreg (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fwinqueryreg (args, nargout);
}

OCTAVE_DEPRECATED (7, "use 'octave::Fzeros' instead")
inline octave_value_list
Fzeros (const octave_value_list& args = octave_value_list (), int nargout = 0)
{
  return octave::Fzeros (args, nargout);
}



#endif

#endif
